# frozen_string_literal: true

# WARNING ABOUT GENERATED CODE
#
# This file is generated. See the contributing guide for more information:
# https://github.com/aws/aws-sdk-ruby/blob/version-3/CONTRIBUTING.md
#
# WARNING ABOUT GENERATED CODE

module Aws::Budgets
  module Types

    # You are not authorized to use this operation with the given
    # parameters.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class AccessDeniedException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # A budget action resource.
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] notification_type
    #   The type of a notification. It must be ACTUAL or FORECASTED.
    #   @return [String]
    #
    # @!attribute [rw] action_type
    #   The type of action. This defines the type of tasks that can be
    #   carried out by this action. This field also determines the format
    #   for definition.
    #   @return [String]
    #
    # @!attribute [rw] action_threshold
    #   The trigger threshold of the action.
    #   @return [Types::ActionThreshold]
    #
    # @!attribute [rw] definition
    #   Where you specify all of the type-specific parameters.
    #   @return [Types::Definition]
    #
    # @!attribute [rw] execution_role_arn
    #   The role passed for action execution and reversion. Roles and
    #   actions must be in the same account.
    #   @return [String]
    #
    # @!attribute [rw] approval_model
    #   This specifies if the action needs manual or automatic approval.
    #   @return [String]
    #
    # @!attribute [rw] status
    #   The status of action.
    #   @return [String]
    #
    # @!attribute [rw] subscribers
    #   A list of subscribers.
    #   @return [Array<Types::Subscriber>]
    #
    class Action < Struct.new(
      :action_id,
      :budget_name,
      :notification_type,
      :action_type,
      :action_threshold,
      :definition,
      :execution_role_arn,
      :approval_model,
      :status,
      :subscribers)
      SENSITIVE = []
      include Aws::Structure
    end

    # The historical records for a budget action.
    #
    # @!attribute [rw] timestamp
    #   A generic time stamp. In Java, it is transformed to a `Date` object.
    #   @return [Time]
    #
    # @!attribute [rw] status
    #   The status of action at the time of the event.
    #   @return [String]
    #
    # @!attribute [rw] event_type
    #   This distinguishes between whether the events are triggered by the
    #   user or generated by the system.
    #   @return [String]
    #
    # @!attribute [rw] action_history_details
    #   The description of details of the event.
    #   @return [Types::ActionHistoryDetails]
    #
    class ActionHistory < Struct.new(
      :timestamp,
      :status,
      :event_type,
      :action_history_details)
      SENSITIVE = []
      include Aws::Structure
    end

    # The description of details of the event.
    #
    # @!attribute [rw] message
    #   A generic string.
    #   @return [String]
    #
    # @!attribute [rw] action
    #   The budget action resource.
    #   @return [Types::Action]
    #
    class ActionHistoryDetails < Struct.new(
      :message,
      :action)
      SENSITIVE = []
      include Aws::Structure
    end

    # The trigger threshold of the action.
    #
    # @note When making an API call, you may pass ActionThreshold
    #   data as a hash:
    #
    #       {
    #         action_threshold_value: 1.0, # required
    #         action_threshold_type: "PERCENTAGE", # required, accepts PERCENTAGE, ABSOLUTE_VALUE
    #       }
    #
    # @!attribute [rw] action_threshold_value
    #   The threshold of a notification.
    #   @return [Float]
    #
    # @!attribute [rw] action_threshold_type
    #   The type of threshold for a notification.
    #   @return [String]
    #
    class ActionThreshold < Struct.new(
      :action_threshold_value,
      :action_threshold_type)
      SENSITIVE = []
      include Aws::Structure
    end

    # Represents the output of the `CreateBudget` operation. The content
    # consists of the detailed metadata and data file information, and the
    # current status of the `budget` object.
    #
    # This is the ARN pattern for a budget:
    #
    # `arn:aws:budgets::AccountId:budget/budgetName`
    #
    # @note When making an API call, you may pass Budget
    #   data as a hash:
    #
    #       {
    #         budget_name: "BudgetName", # required
    #         budget_limit: {
    #           amount: "NumericValue", # required
    #           unit: "UnitValue", # required
    #         },
    #         planned_budget_limits: {
    #           "GenericString" => {
    #             amount: "NumericValue", # required
    #             unit: "UnitValue", # required
    #           },
    #         },
    #         cost_filters: {
    #           "GenericString" => ["GenericString"],
    #         },
    #         cost_types: {
    #           include_tax: false,
    #           include_subscription: false,
    #           use_blended: false,
    #           include_refund: false,
    #           include_credit: false,
    #           include_upfront: false,
    #           include_recurring: false,
    #           include_other_subscription: false,
    #           include_support: false,
    #           include_discount: false,
    #           use_amortized: false,
    #         },
    #         time_unit: "DAILY", # required, accepts DAILY, MONTHLY, QUARTERLY, ANNUALLY
    #         time_period: {
    #           start: Time.now,
    #           end: Time.now,
    #         },
    #         calculated_spend: {
    #           actual_spend: { # required
    #             amount: "NumericValue", # required
    #             unit: "UnitValue", # required
    #           },
    #           forecasted_spend: {
    #             amount: "NumericValue", # required
    #             unit: "UnitValue", # required
    #           },
    #         },
    #         budget_type: "USAGE", # required, accepts USAGE, COST, RI_UTILIZATION, RI_COVERAGE, SAVINGS_PLANS_UTILIZATION, SAVINGS_PLANS_COVERAGE
    #         last_updated_time: Time.now,
    #       }
    #
    # @!attribute [rw] budget_name
    #   The name of a budget. The name must be unique within an account. The
    #   `:` and `` characters aren't allowed in `BudgetName`.
    #   @return [String]
    #
    # @!attribute [rw] budget_limit
    #   The total amount of cost, usage, RI utilization, RI coverage,
    #   Savings Plans utilization, or Savings Plans coverage that you want
    #   to track with your budget.
    #
    #   `BudgetLimit` is required for cost or usage budgets, but optional
    #   for RI or Savings Plans utilization or coverage budgets. RI and
    #   Savings Plans utilization or coverage budgets default to `100`,
    #   which is the only valid value for RI or Savings Plans utilization or
    #   coverage budgets. You can't use `BudgetLimit` with
    #   `PlannedBudgetLimits` for `CreateBudget` and `UpdateBudget` actions.
    #   @return [Types::Spend]
    #
    # @!attribute [rw] planned_budget_limits
    #   A map containing multiple `BudgetLimit`, including current or future
    #   limits.
    #
    #   `PlannedBudgetLimits` is available for cost or usage budget and
    #   supports monthly and quarterly `TimeUnit`.
    #
    #   For monthly budgets, provide 12 months of `PlannedBudgetLimits`
    #   values. This must start from the current month and include the next
    #   11 months. The `key` is the start of the month, `UTC` in epoch
    #   seconds.
    #
    #   For quarterly budgets, provide 4 quarters of `PlannedBudgetLimits`
    #   value entries in standard calendar quarter increments. This must
    #   start from the current quarter and include the next 3 quarters. The
    #   `key` is the start of the quarter, `UTC` in epoch seconds.
    #
    #   If the planned budget expires before 12 months for monthly or 4
    #   quarters for quarterly, provide the `PlannedBudgetLimits` values
    #   only for the remaining periods.
    #
    #   If the budget begins at a date in the future, provide
    #   `PlannedBudgetLimits` values from the start date of the budget.
    #
    #   After all of the `BudgetLimit` values in `PlannedBudgetLimits` are
    #   used, the budget continues to use the last limit as the
    #   `BudgetLimit`. At that point, the planned budget provides the same
    #   experience as a fixed budget.
    #
    #   `DescribeBudget` and `DescribeBudgets` response along with
    #   `PlannedBudgetLimits` will also contain `BudgetLimit` representing
    #   the current month or quarter limit present in `PlannedBudgetLimits`.
    #   This only applies to budgets created with `PlannedBudgetLimits`.
    #   Budgets created without `PlannedBudgetLimits` will only contain
    #   `BudgetLimit`, and no `PlannedBudgetLimits`.
    #   @return [Hash<String,Types::Spend>]
    #
    # @!attribute [rw] cost_filters
    #   The cost filters, such as service or tag, that are applied to a
    #   budget.
    #
    #   AWS Budgets supports the following services as a filter for RI
    #   budgets:
    #
    #   * Amazon Elastic Compute Cloud - Compute
    #
    #   * Amazon Redshift
    #
    #   * Amazon Relational Database Service
    #
    #   * Amazon ElastiCache
    #
    #   * Amazon Elasticsearch Service
    #   @return [Hash<String,Array<String>>]
    #
    # @!attribute [rw] cost_types
    #   The types of costs that are included in this `COST` budget.
    #
    #   `USAGE`, `RI_UTILIZATION`, `RI_COVERAGE`,
    #   `SAVINGS_PLANS_UTILIZATION`, and `SAVINGS_PLANS_COVERAGE` budgets do
    #   not have `CostTypes`.
    #   @return [Types::CostTypes]
    #
    # @!attribute [rw] time_unit
    #   The length of time until a budget resets the actual and forecasted
    #   spend.
    #   @return [String]
    #
    # @!attribute [rw] time_period
    #   The period of time that is covered by a budget. The period has a
    #   start date and an end date. The start date must come before the end
    #   date. The end date must come before `06/15/87 00:00 UTC`.
    #
    #   If you create your budget and don't specify a start date, AWS
    #   defaults to the start of your chosen time period (DAILY, MONTHLY,
    #   QUARTERLY, or ANNUALLY). For example, if you created your budget on
    #   January 24, 2018, chose `DAILY`, and didn't set a start date, AWS
    #   set your start date to `01/24/18 00:00 UTC`. If you chose `MONTHLY`,
    #   AWS set your start date to `01/01/18 00:00 UTC`. If you didn't
    #   specify an end date, AWS set your end date to `06/15/87 00:00 UTC`.
    #   The defaults are the same for the AWS Billing and Cost Management
    #   console and the API.
    #
    #   You can change either date with the `UpdateBudget` operation.
    #
    #   After the end date, AWS deletes the budget and all associated
    #   notifications and subscribers.
    #   @return [Types::TimePeriod]
    #
    # @!attribute [rw] calculated_spend
    #   The actual and forecasted cost or usage that the budget tracks.
    #   @return [Types::CalculatedSpend]
    #
    # @!attribute [rw] budget_type
    #   Whether this budget tracks costs, usage, RI utilization, RI
    #   coverage, Savings Plans utilization, or Savings Plans coverage.
    #   @return [String]
    #
    # @!attribute [rw] last_updated_time
    #   The last time that you updated this budget.
    #   @return [Time]
    #
    class Budget < Struct.new(
      :budget_name,
      :budget_limit,
      :planned_budget_limits,
      :cost_filters,
      :cost_types,
      :time_unit,
      :time_period,
      :calculated_spend,
      :budget_type,
      :last_updated_time)
      SENSITIVE = []
      include Aws::Structure
    end

    # A history of the state of a budget at the end of the budget's
    # specified time period.
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] budget_type
    #   The type of a budget. It must be one of the following types:
    #
    #   `COST`, `USAGE`, `RI_UTILIZATION`, `RI_COVERAGE`,
    #   `SAVINGS_PLANS_UTILIZATION`, or `SAVINGS_PLANS_COVERAGE`.
    #   @return [String]
    #
    # @!attribute [rw] cost_filters
    #   The history of the cost filters for a budget during the specified
    #   time period.
    #   @return [Hash<String,Array<String>>]
    #
    # @!attribute [rw] cost_types
    #   The history of the cost types for a budget during the specified time
    #   period.
    #   @return [Types::CostTypes]
    #
    # @!attribute [rw] time_unit
    #   The time unit of the budget, such as MONTHLY or QUARTERLY.
    #   @return [String]
    #
    # @!attribute [rw] budgeted_and_actual_amounts_list
    #   A list of amounts of cost or usage that you created budgets for,
    #   compared to your actual costs or usage.
    #   @return [Array<Types::BudgetedAndActualAmounts>]
    #
    class BudgetPerformanceHistory < Struct.new(
      :budget_name,
      :budget_type,
      :cost_filters,
      :cost_types,
      :time_unit,
      :budgeted_and_actual_amounts_list)
      SENSITIVE = []
      include Aws::Structure
    end

    # The amount of cost or usage that you created the budget for, compared
    # to your actual costs or usage.
    #
    # @!attribute [rw] budgeted_amount
    #   The amount of cost or usage that you created the budget for.
    #   @return [Types::Spend]
    #
    # @!attribute [rw] actual_amount
    #   Your actual costs or usage for a budget period.
    #   @return [Types::Spend]
    #
    # @!attribute [rw] time_period
    #   The time period covered by this budget comparison.
    #   @return [Types::TimePeriod]
    #
    class BudgetedAndActualAmounts < Struct.new(
      :budgeted_amount,
      :actual_amount,
      :time_period)
      SENSITIVE = []
      include Aws::Structure
    end

    # The spend objects that are associated with this budget. The
    # `actualSpend` tracks how much you've used, cost, usage, RI units, or
    # Savings Plans units and the `forecastedSpend` tracks how much you are
    # predicted to spend based on your historical usage profile.
    #
    # For example, if it is the 20th of the month and you have spent `50`
    # dollars on Amazon EC2, your `actualSpend` is `50 USD`, and your
    # `forecastedSpend` is `75 USD`.
    #
    # @note When making an API call, you may pass CalculatedSpend
    #   data as a hash:
    #
    #       {
    #         actual_spend: { # required
    #           amount: "NumericValue", # required
    #           unit: "UnitValue", # required
    #         },
    #         forecasted_spend: {
    #           amount: "NumericValue", # required
    #           unit: "UnitValue", # required
    #         },
    #       }
    #
    # @!attribute [rw] actual_spend
    #   The amount of cost, usage, RI units, or Savings Plans units that you
    #   have used.
    #   @return [Types::Spend]
    #
    # @!attribute [rw] forecasted_spend
    #   The amount of cost, usage, RI units, or Savings Plans units that you
    #   are forecasted to use.
    #   @return [Types::Spend]
    #
    class CalculatedSpend < Struct.new(
      :actual_spend,
      :forecasted_spend)
      SENSITIVE = []
      include Aws::Structure
    end

    # The types of cost that are included in a `COST` budget, such as tax
    # and subscriptions.
    #
    # `USAGE`, `RI_UTILIZATION`, `RI_COVERAGE`, `SAVINGS_PLANS_UTILIZATION`,
    # and `SAVINGS_PLANS_COVERAGE` budgets do not have `CostTypes`.
    #
    # @note When making an API call, you may pass CostTypes
    #   data as a hash:
    #
    #       {
    #         include_tax: false,
    #         include_subscription: false,
    #         use_blended: false,
    #         include_refund: false,
    #         include_credit: false,
    #         include_upfront: false,
    #         include_recurring: false,
    #         include_other_subscription: false,
    #         include_support: false,
    #         include_discount: false,
    #         use_amortized: false,
    #       }
    #
    # @!attribute [rw] include_tax
    #   Specifies whether a budget includes taxes.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_subscription
    #   Specifies whether a budget includes subscriptions.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] use_blended
    #   Specifies whether a budget uses a blended rate.
    #
    #   The default value is `false`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_refund
    #   Specifies whether a budget includes refunds.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_credit
    #   Specifies whether a budget includes credits.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_upfront
    #   Specifies whether a budget includes upfront RI costs.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_recurring
    #   Specifies whether a budget includes recurring fees such as monthly
    #   RI fees.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_other_subscription
    #   Specifies whether a budget includes non-RI subscription costs.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_support
    #   Specifies whether a budget includes support subscription fees.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] include_discount
    #   Specifies whether a budget includes discounts.
    #
    #   The default value is `true`.
    #   @return [Boolean]
    #
    # @!attribute [rw] use_amortized
    #   Specifies whether a budget uses the amortized rate.
    #
    #   The default value is `false`.
    #   @return [Boolean]
    #
    class CostTypes < Struct.new(
      :include_tax,
      :include_subscription,
      :use_blended,
      :include_refund,
      :include_credit,
      :include_upfront,
      :include_recurring,
      :include_other_subscription,
      :include_support,
      :include_discount,
      :use_amortized)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass CreateBudgetActionRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #         action_type: "APPLY_IAM_POLICY", # required, accepts APPLY_IAM_POLICY, APPLY_SCP_POLICY, RUN_SSM_DOCUMENTS
    #         action_threshold: { # required
    #           action_threshold_value: 1.0, # required
    #           action_threshold_type: "PERCENTAGE", # required, accepts PERCENTAGE, ABSOLUTE_VALUE
    #         },
    #         definition: { # required
    #           iam_action_definition: {
    #             policy_arn: "PolicyArn", # required
    #             roles: ["Role"],
    #             groups: ["Group"],
    #             users: ["User"],
    #           },
    #           scp_action_definition: {
    #             policy_id: "PolicyId", # required
    #             target_ids: ["TargetId"], # required
    #           },
    #           ssm_action_definition: {
    #             action_sub_type: "STOP_EC2_INSTANCES", # required, accepts STOP_EC2_INSTANCES, STOP_RDS_INSTANCES
    #             region: "Region", # required
    #             instance_ids: ["InstanceId"], # required
    #           },
    #         },
    #         execution_role_arn: "RoleArn", # required
    #         approval_model: "AUTOMATIC", # required, accepts AUTOMATIC, MANUAL
    #         subscribers: [ # required
    #           {
    #             subscription_type: "SNS", # required, accepts SNS, EMAIL
    #             address: "SubscriberAddress", # required
    #           },
    #         ],
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] notification_type
    #   The type of a notification. It must be ACTUAL or FORECASTED.
    #   @return [String]
    #
    # @!attribute [rw] action_type
    #   The type of action. This defines the type of tasks that can be
    #   carried out by this action. This field also determines the format
    #   for definition.
    #   @return [String]
    #
    # @!attribute [rw] action_threshold
    #   The trigger threshold of the action.
    #   @return [Types::ActionThreshold]
    #
    # @!attribute [rw] definition
    #   Specifies all of the type-specific parameters.
    #   @return [Types::Definition]
    #
    # @!attribute [rw] execution_role_arn
    #   The role passed for action execution and reversion. Roles and
    #   actions must be in the same account.
    #   @return [String]
    #
    # @!attribute [rw] approval_model
    #   This specifies if the action needs manual or automatic approval.
    #   @return [String]
    #
    # @!attribute [rw] subscribers
    #   A list of subscribers.
    #   @return [Array<Types::Subscriber>]
    #
    class CreateBudgetActionRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification_type,
      :action_type,
      :action_threshold,
      :definition,
      :execution_role_arn,
      :approval_model,
      :subscribers)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    class CreateBudgetActionResponse < Struct.new(
      :account_id,
      :budget_name,
      :action_id)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of CreateBudget
    #
    # @note When making an API call, you may pass CreateBudgetRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget: { # required
    #           budget_name: "BudgetName", # required
    #           budget_limit: {
    #             amount: "NumericValue", # required
    #             unit: "UnitValue", # required
    #           },
    #           planned_budget_limits: {
    #             "GenericString" => {
    #               amount: "NumericValue", # required
    #               unit: "UnitValue", # required
    #             },
    #           },
    #           cost_filters: {
    #             "GenericString" => ["GenericString"],
    #           },
    #           cost_types: {
    #             include_tax: false,
    #             include_subscription: false,
    #             use_blended: false,
    #             include_refund: false,
    #             include_credit: false,
    #             include_upfront: false,
    #             include_recurring: false,
    #             include_other_subscription: false,
    #             include_support: false,
    #             include_discount: false,
    #             use_amortized: false,
    #           },
    #           time_unit: "DAILY", # required, accepts DAILY, MONTHLY, QUARTERLY, ANNUALLY
    #           time_period: {
    #             start: Time.now,
    #             end: Time.now,
    #           },
    #           calculated_spend: {
    #             actual_spend: { # required
    #               amount: "NumericValue", # required
    #               unit: "UnitValue", # required
    #             },
    #             forecasted_spend: {
    #               amount: "NumericValue", # required
    #               unit: "UnitValue", # required
    #             },
    #           },
    #           budget_type: "USAGE", # required, accepts USAGE, COST, RI_UTILIZATION, RI_COVERAGE, SAVINGS_PLANS_UTILIZATION, SAVINGS_PLANS_COVERAGE
    #           last_updated_time: Time.now,
    #         },
    #         notifications_with_subscribers: [
    #           {
    #             notification: { # required
    #               notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #               comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #               threshold: 1.0, # required
    #               threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #               notification_state: "OK", # accepts OK, ALARM
    #             },
    #             subscribers: [ # required
    #               {
    #                 subscription_type: "SNS", # required, accepts SNS, EMAIL
    #                 address: "SubscriberAddress", # required
    #               },
    #             ],
    #           },
    #         ],
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget.
    #   @return [String]
    #
    # @!attribute [rw] budget
    #   The budget object that you want to create.
    #   @return [Types::Budget]
    #
    # @!attribute [rw] notifications_with_subscribers
    #   A notification that you want to associate with a budget. A budget
    #   can have up to five notifications, and each notification can have
    #   one SNS subscriber and up to 10 email subscribers. If you include
    #   notifications and subscribers in your `CreateBudget` call, AWS
    #   creates the notifications and subscribers for you.
    #   @return [Array<Types::NotificationWithSubscribers>]
    #
    class CreateBudgetRequest < Struct.new(
      :account_id,
      :budget,
      :notifications_with_subscribers)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of CreateBudget
    #
    class CreateBudgetResponse < Aws::EmptyStructure; end

    # Request of CreateNotification
    #
    # @note When making an API call, you may pass CreateNotificationRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         subscribers: [ # required
    #           {
    #             subscription_type: "SNS", # required, accepts SNS, EMAIL
    #             address: "SubscriberAddress", # required
    #           },
    #         ],
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget that you want to
    #   create a notification for.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget that you want AWS to notify you about. Budget
    #   names must be unique within an account.
    #   @return [String]
    #
    # @!attribute [rw] notification
    #   The notification that you want to create.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] subscribers
    #   A list of subscribers that you want to associate with the
    #   notification. Each notification can have one SNS subscriber and up
    #   to 10 email subscribers.
    #   @return [Array<Types::Subscriber>]
    #
    class CreateNotificationRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification,
      :subscribers)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of CreateNotification
    #
    class CreateNotificationResponse < Aws::EmptyStructure; end

    # Request of CreateSubscriber
    #
    # @note When making an API call, you may pass CreateSubscriberRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         subscriber: { # required
    #           subscription_type: "SNS", # required, accepts SNS, EMAIL
    #           address: "SubscriberAddress", # required
    #         },
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget that you want to
    #   create a subscriber for.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget that you want to subscribe to. Budget names
    #   must be unique within an account.
    #   @return [String]
    #
    # @!attribute [rw] notification
    #   The notification that you want to create a subscriber for.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] subscriber
    #   The subscriber that you want to associate with a budget
    #   notification.
    #   @return [Types::Subscriber]
    #
    class CreateSubscriberRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification,
      :subscriber)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of CreateSubscriber
    #
    class CreateSubscriberResponse < Aws::EmptyStructure; end

    # You've exceeded the notification or subscriber limit.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class CreationLimitExceededException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # Specifies all of the type-specific parameters.
    #
    # @note When making an API call, you may pass Definition
    #   data as a hash:
    #
    #       {
    #         iam_action_definition: {
    #           policy_arn: "PolicyArn", # required
    #           roles: ["Role"],
    #           groups: ["Group"],
    #           users: ["User"],
    #         },
    #         scp_action_definition: {
    #           policy_id: "PolicyId", # required
    #           target_ids: ["TargetId"], # required
    #         },
    #         ssm_action_definition: {
    #           action_sub_type: "STOP_EC2_INSTANCES", # required, accepts STOP_EC2_INSTANCES, STOP_RDS_INSTANCES
    #           region: "Region", # required
    #           instance_ids: ["InstanceId"], # required
    #         },
    #       }
    #
    # @!attribute [rw] iam_action_definition
    #   The AWS Identity and Access Management (IAM) action definition
    #   details.
    #   @return [Types::IamActionDefinition]
    #
    # @!attribute [rw] scp_action_definition
    #   The service control policies (SCPs) action definition details.
    #   @return [Types::ScpActionDefinition]
    #
    # @!attribute [rw] ssm_action_definition
    #   The AWS Systems Manager (SSM) action definition details.
    #   @return [Types::SsmActionDefinition]
    #
    class Definition < Struct.new(
      :iam_action_definition,
      :scp_action_definition,
      :ssm_action_definition)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass DeleteBudgetActionRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         action_id: "ActionId", # required
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    class DeleteBudgetActionRequest < Struct.new(
      :account_id,
      :budget_name,
      :action_id)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action
    #   A budget action resource.
    #   @return [Types::Action]
    #
    class DeleteBudgetActionResponse < Struct.new(
      :account_id,
      :budget_name,
      :action)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of DeleteBudget
    #
    # @note When making an API call, you may pass DeleteBudgetRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget that you want to
    #   delete.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget that you want to delete.
    #   @return [String]
    #
    class DeleteBudgetRequest < Struct.new(
      :account_id,
      :budget_name)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of DeleteBudget
    #
    class DeleteBudgetResponse < Aws::EmptyStructure; end

    # Request of DeleteNotification
    #
    # @note When making an API call, you may pass DeleteNotificationRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget whose
    #   notification you want to delete.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget whose notification you want to delete.
    #   @return [String]
    #
    # @!attribute [rw] notification
    #   The notification that you want to delete.
    #   @return [Types::Notification]
    #
    class DeleteNotificationRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of DeleteNotification
    #
    class DeleteNotificationResponse < Aws::EmptyStructure; end

    # Request of DeleteSubscriber
    #
    # @note When making an API call, you may pass DeleteSubscriberRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         subscriber: { # required
    #           subscription_type: "SNS", # required, accepts SNS, EMAIL
    #           address: "SubscriberAddress", # required
    #         },
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget whose subscriber
    #   you want to delete.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget whose subscriber you want to delete.
    #   @return [String]
    #
    # @!attribute [rw] notification
    #   The notification whose subscriber you want to delete.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] subscriber
    #   The subscriber that you want to delete.
    #   @return [Types::Subscriber]
    #
    class DeleteSubscriberRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification,
      :subscriber)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of DeleteSubscriber
    #
    class DeleteSubscriberResponse < Aws::EmptyStructure; end

    # @note When making an API call, you may pass DescribeBudgetActionHistoriesRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         action_id: "ActionId", # required
    #         time_period: {
    #           start: Time.now,
    #           end: Time.now,
    #         },
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    # @!attribute [rw] time_period
    #   The period of time that is covered by a budget. The period has a
    #   start date and an end date. The start date must come before the end
    #   date. There are no restrictions on the end date.
    #   @return [Types::TimePeriod]
    #
    # @!attribute [rw] max_results
    #   An integer that represents how many entries a paginated response
    #   contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetActionHistoriesRequest < Struct.new(
      :account_id,
      :budget_name,
      :action_id,
      :time_period,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] action_histories
    #   The historical record of the budget action resource.
    #   @return [Array<Types::ActionHistory>]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetActionHistoriesResponse < Struct.new(
      :action_histories,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass DescribeBudgetActionRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         action_id: "ActionId", # required
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    class DescribeBudgetActionRequest < Struct.new(
      :account_id,
      :budget_name,
      :action_id)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action
    #   A budget action resource.
    #   @return [Types::Action]
    #
    class DescribeBudgetActionResponse < Struct.new(
      :account_id,
      :budget_name,
      :action)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass DescribeBudgetActionsForAccountRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] max_results
    #   An integer that represents how many entries a paginated response
    #   contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetActionsForAccountRequest < Struct.new(
      :account_id,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] actions
    #   A list of the budget action resources information.
    #   @return [Array<Types::Action>]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetActionsForAccountResponse < Struct.new(
      :actions,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass DescribeBudgetActionsForBudgetRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] max_results
    #   An integer that represents how many entries a paginated response
    #   contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetActionsForBudgetRequest < Struct.new(
      :account_id,
      :budget_name,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] actions
    #   A list of the budget action resources information.
    #   @return [Array<Types::Action>]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetActionsForBudgetResponse < Struct.new(
      :actions,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass DescribeBudgetPerformanceHistoryRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         time_period: {
    #           start: Time.now,
    #           end: Time.now,
    #         },
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] time_period
    #   Retrieves how often the budget went into an `ALARM` state for the
    #   specified time period.
    #   @return [Types::TimePeriod]
    #
    # @!attribute [rw] max_results
    #   An integer that represents how many entries a paginated response
    #   contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetPerformanceHistoryRequest < Struct.new(
      :account_id,
      :budget_name,
      :time_period,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] budget_performance_history
    #   The history of how often the budget has gone into an `ALARM` state.
    #
    #   For `DAILY` budgets, the history saves the state of the budget for
    #   the last 60 days. For `MONTHLY` budgets, the history saves the state
    #   of the budget for the current month plus the last 12 months. For
    #   `QUARTERLY` budgets, the history saves the state of the budget for
    #   the last four quarters.
    #   @return [Types::BudgetPerformanceHistory]
    #
    # @!attribute [rw] next_token
    #   A generic string.
    #   @return [String]
    #
    class DescribeBudgetPerformanceHistoryResponse < Struct.new(
      :budget_performance_history,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of DescribeBudget
    #
    # @note When making an API call, you may pass DescribeBudgetRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget that you want a
    #   description of.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget that you want a description of.
    #   @return [String]
    #
    class DescribeBudgetRequest < Struct.new(
      :account_id,
      :budget_name)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of DescribeBudget
    #
    # @!attribute [rw] budget
    #   The description of the budget.
    #   @return [Types::Budget]
    #
    class DescribeBudgetResponse < Struct.new(
      :budget)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of DescribeBudgets
    #
    # @note When making an API call, you may pass DescribeBudgetsRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budgets that you want
    #   descriptions of.
    #   @return [String]
    #
    # @!attribute [rw] max_results
    #   An optional integer that represents how many entries a paginated
    #   response contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   The pagination token that you include in your request to indicate
    #   the next set of results that you want to retrieve.
    #   @return [String]
    #
    class DescribeBudgetsRequest < Struct.new(
      :account_id,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of DescribeBudgets
    #
    # @!attribute [rw] budgets
    #   A list of budgets.
    #   @return [Array<Types::Budget>]
    #
    # @!attribute [rw] next_token
    #   The pagination token in the service response that indicates the next
    #   set of results that you can retrieve.
    #   @return [String]
    #
    class DescribeBudgetsResponse < Struct.new(
      :budgets,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of DescribeNotificationsForBudget
    #
    # @note When making an API call, you may pass DescribeNotificationsForBudgetRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget whose
    #   notifications you want descriptions of.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget whose notifications you want descriptions of.
    #   @return [String]
    #
    # @!attribute [rw] max_results
    #   An optional integer that represents how many entries a paginated
    #   response contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   The pagination token that you include in your request to indicate
    #   the next set of results that you want to retrieve.
    #   @return [String]
    #
    class DescribeNotificationsForBudgetRequest < Struct.new(
      :account_id,
      :budget_name,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of GetNotificationsForBudget
    #
    # @!attribute [rw] notifications
    #   A list of notifications that are associated with a budget.
    #   @return [Array<Types::Notification>]
    #
    # @!attribute [rw] next_token
    #   The pagination token in the service response that indicates the next
    #   set of results that you can retrieve.
    #   @return [String]
    #
    class DescribeNotificationsForBudgetResponse < Struct.new(
      :notifications,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of DescribeSubscribersForNotification
    #
    # @note When making an API call, you may pass DescribeSubscribersForNotificationRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         max_results: 1,
    #         next_token: "GenericString",
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget whose subscribers
    #   you want descriptions of.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget whose subscribers you want descriptions of.
    #   @return [String]
    #
    # @!attribute [rw] notification
    #   The notification whose subscribers you want to list.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] max_results
    #   An optional integer that represents how many entries a paginated
    #   response contains. The maximum is 100.
    #   @return [Integer]
    #
    # @!attribute [rw] next_token
    #   The pagination token that you include in your request to indicate
    #   the next set of results that you want to retrieve.
    #   @return [String]
    #
    class DescribeSubscribersForNotificationRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification,
      :max_results,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of DescribeSubscribersForNotification
    #
    # @!attribute [rw] subscribers
    #   A list of subscribers that are associated with a notification.
    #   @return [Array<Types::Subscriber>]
    #
    # @!attribute [rw] next_token
    #   The pagination token in the service response that indicates the next
    #   set of results that you can retrieve.
    #   @return [String]
    #
    class DescribeSubscribersForNotificationResponse < Struct.new(
      :subscribers,
      :next_token)
      SENSITIVE = []
      include Aws::Structure
    end

    # The budget name already exists. Budget names must be unique within an
    # account.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class DuplicateRecordException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass ExecuteBudgetActionRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         action_id: "ActionId", # required
    #         execution_type: "APPROVE_BUDGET_ACTION", # required, accepts APPROVE_BUDGET_ACTION, RETRY_BUDGET_ACTION, REVERSE_BUDGET_ACTION, RESET_BUDGET_ACTION
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    # @!attribute [rw] execution_type
    #   The type of execution.
    #   @return [String]
    #
    class ExecuteBudgetActionRequest < Struct.new(
      :account_id,
      :budget_name,
      :action_id,
      :execution_type)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    # @!attribute [rw] execution_type
    #   The type of execution.
    #   @return [String]
    #
    class ExecuteBudgetActionResponse < Struct.new(
      :account_id,
      :budget_name,
      :action_id,
      :execution_type)
      SENSITIVE = []
      include Aws::Structure
    end

    # The pagination token expired.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class ExpiredNextTokenException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # The AWS Identity and Access Management (IAM) action definition
    # details.
    #
    # @note When making an API call, you may pass IamActionDefinition
    #   data as a hash:
    #
    #       {
    #         policy_arn: "PolicyArn", # required
    #         roles: ["Role"],
    #         groups: ["Group"],
    #         users: ["User"],
    #       }
    #
    # @!attribute [rw] policy_arn
    #   The Amazon Resource Name (ARN) of the policy to be attached.
    #   @return [String]
    #
    # @!attribute [rw] roles
    #   A list of roles to be attached. There must be at least one role.
    #   @return [Array<String>]
    #
    # @!attribute [rw] groups
    #   A list of groups to be attached. There must be at least one group.
    #   @return [Array<String>]
    #
    # @!attribute [rw] users
    #   A list of users to be attached. There must be at least one user.
    #   @return [Array<String>]
    #
    class IamActionDefinition < Struct.new(
      :policy_arn,
      :roles,
      :groups,
      :users)
      SENSITIVE = []
      include Aws::Structure
    end

    # An error on the server occurred during the processing of your request.
    # Try again later.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class InternalErrorException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # The pagination token is invalid.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class InvalidNextTokenException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # An error on the client occurred. Typically, the cause is an invalid
    # input value.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class InvalidParameterException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # We can’t locate the resource that you specified.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class NotFoundException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # A notification that is associated with a budget. A budget can have up
    # to ten notifications.
    #
    # Each notification must have at least one subscriber. A notification
    # can have one SNS subscriber and up to 10 email subscribers, for a
    # total of 11 subscribers.
    #
    # For example, if you have a budget for 200 dollars and you want to be
    # notified when you go over 160 dollars, create a notification with the
    # following parameters:
    #
    # * A notificationType of `ACTUAL`
    #
    # * A `thresholdType` of `PERCENTAGE`
    #
    # * A `comparisonOperator` of `GREATER_THAN`
    #
    # * A notification `threshold` of `80`
    #
    # @note When making an API call, you may pass Notification
    #   data as a hash:
    #
    #       {
    #         notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #         comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #         threshold: 1.0, # required
    #         threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #         notification_state: "OK", # accepts OK, ALARM
    #       }
    #
    # @!attribute [rw] notification_type
    #   Whether the notification is for how much you have spent (`ACTUAL`)
    #   or for how much you're forecasted to spend (`FORECASTED`).
    #   @return [String]
    #
    # @!attribute [rw] comparison_operator
    #   The comparison that is used for this notification.
    #   @return [String]
    #
    # @!attribute [rw] threshold
    #   The threshold that is associated with a notification. Thresholds are
    #   always a percentage, and many customers find value being alerted
    #   between 50% - 200% of the budgeted amount. The maximum limit for
    #   your threshold is 1,000,000% above the budgeted amount.
    #   @return [Float]
    #
    # @!attribute [rw] threshold_type
    #   The type of threshold for a notification. For `ABSOLUTE_VALUE`
    #   thresholds, AWS notifies you when you go over or are forecasted to
    #   go over your total cost threshold. For `PERCENTAGE` thresholds, AWS
    #   notifies you when you go over or are forecasted to go over a certain
    #   percentage of your forecasted spend. For example, if you have a
    #   budget for 200 dollars and you have a `PERCENTAGE` threshold of 80%,
    #   AWS notifies you when you go over 160 dollars.
    #   @return [String]
    #
    # @!attribute [rw] notification_state
    #   Whether this notification is in alarm. If a budget notification is
    #   in the `ALARM` state, you have passed the set threshold for the
    #   budget.
    #   @return [String]
    #
    class Notification < Struct.new(
      :notification_type,
      :comparison_operator,
      :threshold,
      :threshold_type,
      :notification_state)
      SENSITIVE = []
      include Aws::Structure
    end

    # A notification with subscribers. A notification can have one SNS
    # subscriber and up to 10 email subscribers, for a total of 11
    # subscribers.
    #
    # @note When making an API call, you may pass NotificationWithSubscribers
    #   data as a hash:
    #
    #       {
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         subscribers: [ # required
    #           {
    #             subscription_type: "SNS", # required, accepts SNS, EMAIL
    #             address: "SubscriberAddress", # required
    #           },
    #         ],
    #       }
    #
    # @!attribute [rw] notification
    #   The notification that is associated with a budget.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] subscribers
    #   A list of subscribers who are subscribed to this notification.
    #   @return [Array<Types::Subscriber>]
    #
    class NotificationWithSubscribers < Struct.new(
      :notification,
      :subscribers)
      SENSITIVE = []
      include Aws::Structure
    end

    # The request was received and recognized by the server, but the server
    # rejected that particular method for the requested resource.
    #
    # @!attribute [rw] message
    #   The error message the exception carries.
    #   @return [String]
    #
    class ResourceLockedException < Struct.new(
      :message)
      SENSITIVE = []
      include Aws::Structure
    end

    # The service control policies (SCP) action definition details.
    #
    # @note When making an API call, you may pass ScpActionDefinition
    #   data as a hash:
    #
    #       {
    #         policy_id: "PolicyId", # required
    #         target_ids: ["TargetId"], # required
    #       }
    #
    # @!attribute [rw] policy_id
    #   The policy ID attached.
    #   @return [String]
    #
    # @!attribute [rw] target_ids
    #   A list of target IDs.
    #   @return [Array<String>]
    #
    class ScpActionDefinition < Struct.new(
      :policy_id,
      :target_ids)
      SENSITIVE = []
      include Aws::Structure
    end

    # The amount of cost or usage that is measured for a budget.
    #
    # For example, a `Spend` for `3 GB` of S3 usage would have the following
    # parameters:
    #
    # * An `Amount` of `3`
    #
    # * A `unit` of `GB`
    #
    # @note When making an API call, you may pass Spend
    #   data as a hash:
    #
    #       {
    #         amount: "NumericValue", # required
    #         unit: "UnitValue", # required
    #       }
    #
    # @!attribute [rw] amount
    #   The cost or usage amount that is associated with a budget forecast,
    #   actual spend, or budget threshold.
    #   @return [String]
    #
    # @!attribute [rw] unit
    #   The unit of measurement that is used for the budget forecast, actual
    #   spend, or budget threshold, such as dollars or GB.
    #   @return [String]
    #
    class Spend < Struct.new(
      :amount,
      :unit)
      SENSITIVE = []
      include Aws::Structure
    end

    # The AWS Systems Manager (SSM) action definition details.
    #
    # @note When making an API call, you may pass SsmActionDefinition
    #   data as a hash:
    #
    #       {
    #         action_sub_type: "STOP_EC2_INSTANCES", # required, accepts STOP_EC2_INSTANCES, STOP_RDS_INSTANCES
    #         region: "Region", # required
    #         instance_ids: ["InstanceId"], # required
    #       }
    #
    # @!attribute [rw] action_sub_type
    #   The action subType.
    #   @return [String]
    #
    # @!attribute [rw] region
    #   The Region to run the SSM document.
    #   @return [String]
    #
    # @!attribute [rw] instance_ids
    #   The EC2 and RDS instance IDs.
    #   @return [Array<String>]
    #
    class SsmActionDefinition < Struct.new(
      :action_sub_type,
      :region,
      :instance_ids)
      SENSITIVE = []
      include Aws::Structure
    end

    # The subscriber to a budget notification. The subscriber consists of a
    # subscription type and either an Amazon SNS topic or an email address.
    #
    # For example, an email subscriber would have the following parameters:
    #
    # * A `subscriptionType` of `EMAIL`
    #
    # * An `address` of `example@example.com`
    #
    # @note When making an API call, you may pass Subscriber
    #   data as a hash:
    #
    #       {
    #         subscription_type: "SNS", # required, accepts SNS, EMAIL
    #         address: "SubscriberAddress", # required
    #       }
    #
    # @!attribute [rw] subscription_type
    #   The type of notification that AWS sends to a subscriber.
    #   @return [String]
    #
    # @!attribute [rw] address
    #   The address that AWS sends budget notifications to, either an SNS
    #   topic or an email.
    #
    #   When you create a subscriber, the value of `Address` can't contain
    #   line breaks.
    #   @return [String]
    #
    class Subscriber < Struct.new(
      :subscription_type,
      :address)
      SENSITIVE = [:address]
      include Aws::Structure
    end

    # The period of time that is covered by a budget. The period has a start
    # date and an end date. The start date must come before the end date.
    # There are no restrictions on the end date.
    #
    # @note When making an API call, you may pass TimePeriod
    #   data as a hash:
    #
    #       {
    #         start: Time.now,
    #         end: Time.now,
    #       }
    #
    # @!attribute [rw] start
    #   The start date for a budget. If you created your budget and didn't
    #   specify a start date, AWS defaults to the start of your chosen time
    #   period (DAILY, MONTHLY, QUARTERLY, or ANNUALLY). For example, if you
    #   created your budget on January 24, 2018, chose `DAILY`, and didn't
    #   set a start date, AWS set your start date to `01/24/18 00:00 UTC`.
    #   If you chose `MONTHLY`, AWS set your start date to `01/01/18 00:00
    #   UTC`. The defaults are the same for the AWS Billing and Cost
    #   Management console and the API.
    #
    #   You can change your start date with the `UpdateBudget` operation.
    #   @return [Time]
    #
    # @!attribute [rw] end
    #   The end date for a budget. If you didn't specify an end date, AWS
    #   set your end date to `06/15/87 00:00 UTC`. The defaults are the same
    #   for the AWS Billing and Cost Management console and the API.
    #
    #   After the end date, AWS deletes the budget and all associated
    #   notifications and subscribers. You can change your end date with the
    #   `UpdateBudget` operation.
    #   @return [Time]
    #
    class TimePeriod < Struct.new(
      :start,
      :end)
      SENSITIVE = []
      include Aws::Structure
    end

    # @note When making an API call, you may pass UpdateBudgetActionRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         action_id: "ActionId", # required
    #         notification_type: "ACTUAL", # accepts ACTUAL, FORECASTED
    #         action_threshold: {
    #           action_threshold_value: 1.0, # required
    #           action_threshold_type: "PERCENTAGE", # required, accepts PERCENTAGE, ABSOLUTE_VALUE
    #         },
    #         definition: {
    #           iam_action_definition: {
    #             policy_arn: "PolicyArn", # required
    #             roles: ["Role"],
    #             groups: ["Group"],
    #             users: ["User"],
    #           },
    #           scp_action_definition: {
    #             policy_id: "PolicyId", # required
    #             target_ids: ["TargetId"], # required
    #           },
    #           ssm_action_definition: {
    #             action_sub_type: "STOP_EC2_INSTANCES", # required, accepts STOP_EC2_INSTANCES, STOP_RDS_INSTANCES
    #             region: "Region", # required
    #             instance_ids: ["InstanceId"], # required
    #           },
    #         },
    #         execution_role_arn: "RoleArn",
    #         approval_model: "AUTOMATIC", # accepts AUTOMATIC, MANUAL
    #         subscribers: [
    #           {
    #             subscription_type: "SNS", # required, accepts SNS, EMAIL
    #             address: "SubscriberAddress", # required
    #           },
    #         ],
    #       }
    #
    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] action_id
    #   A system-generated universally unique identifier (UUID) for the
    #   action.
    #   @return [String]
    #
    # @!attribute [rw] notification_type
    #   The type of a notification. It must be ACTUAL or FORECASTED.
    #   @return [String]
    #
    # @!attribute [rw] action_threshold
    #   The trigger threshold of the action.
    #   @return [Types::ActionThreshold]
    #
    # @!attribute [rw] definition
    #   Specifies all of the type-specific parameters.
    #   @return [Types::Definition]
    #
    # @!attribute [rw] execution_role_arn
    #   The role passed for action execution and reversion. Roles and
    #   actions must be in the same account.
    #   @return [String]
    #
    # @!attribute [rw] approval_model
    #   This specifies if the action needs manual or automatic approval.
    #   @return [String]
    #
    # @!attribute [rw] subscribers
    #   A list of subscribers.
    #   @return [Array<Types::Subscriber>]
    #
    class UpdateBudgetActionRequest < Struct.new(
      :account_id,
      :budget_name,
      :action_id,
      :notification_type,
      :action_threshold,
      :definition,
      :execution_role_arn,
      :approval_model,
      :subscribers)
      SENSITIVE = []
      include Aws::Structure
    end

    # @!attribute [rw] account_id
    #   The account ID of the user. It should be a 12-digit number.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   A string that represents the budget name. The ":" and "\\"
    #   characters aren't allowed.
    #   @return [String]
    #
    # @!attribute [rw] old_action
    #   The previous action resource information.
    #   @return [Types::Action]
    #
    # @!attribute [rw] new_action
    #   The updated action resource information.
    #   @return [Types::Action]
    #
    class UpdateBudgetActionResponse < Struct.new(
      :account_id,
      :budget_name,
      :old_action,
      :new_action)
      SENSITIVE = []
      include Aws::Structure
    end

    # Request of UpdateBudget
    #
    # @note When making an API call, you may pass UpdateBudgetRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         new_budget: { # required
    #           budget_name: "BudgetName", # required
    #           budget_limit: {
    #             amount: "NumericValue", # required
    #             unit: "UnitValue", # required
    #           },
    #           planned_budget_limits: {
    #             "GenericString" => {
    #               amount: "NumericValue", # required
    #               unit: "UnitValue", # required
    #             },
    #           },
    #           cost_filters: {
    #             "GenericString" => ["GenericString"],
    #           },
    #           cost_types: {
    #             include_tax: false,
    #             include_subscription: false,
    #             use_blended: false,
    #             include_refund: false,
    #             include_credit: false,
    #             include_upfront: false,
    #             include_recurring: false,
    #             include_other_subscription: false,
    #             include_support: false,
    #             include_discount: false,
    #             use_amortized: false,
    #           },
    #           time_unit: "DAILY", # required, accepts DAILY, MONTHLY, QUARTERLY, ANNUALLY
    #           time_period: {
    #             start: Time.now,
    #             end: Time.now,
    #           },
    #           calculated_spend: {
    #             actual_spend: { # required
    #               amount: "NumericValue", # required
    #               unit: "UnitValue", # required
    #             },
    #             forecasted_spend: {
    #               amount: "NumericValue", # required
    #               unit: "UnitValue", # required
    #             },
    #           },
    #           budget_type: "USAGE", # required, accepts USAGE, COST, RI_UTILIZATION, RI_COVERAGE, SAVINGS_PLANS_UTILIZATION, SAVINGS_PLANS_COVERAGE
    #           last_updated_time: Time.now,
    #         },
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget that you want to
    #   update.
    #   @return [String]
    #
    # @!attribute [rw] new_budget
    #   The budget that you want to update your budget to.
    #   @return [Types::Budget]
    #
    class UpdateBudgetRequest < Struct.new(
      :account_id,
      :new_budget)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of UpdateBudget
    #
    class UpdateBudgetResponse < Aws::EmptyStructure; end

    # Request of UpdateNotification
    #
    # @note When making an API call, you may pass UpdateNotificationRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         old_notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         new_notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget whose
    #   notification you want to update.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget whose notification you want to update.
    #   @return [String]
    #
    # @!attribute [rw] old_notification
    #   The previous notification that is associated with a budget.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] new_notification
    #   The updated notification to be associated with a budget.
    #   @return [Types::Notification]
    #
    class UpdateNotificationRequest < Struct.new(
      :account_id,
      :budget_name,
      :old_notification,
      :new_notification)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of UpdateNotification
    #
    class UpdateNotificationResponse < Aws::EmptyStructure; end

    # Request of UpdateSubscriber
    #
    # @note When making an API call, you may pass UpdateSubscriberRequest
    #   data as a hash:
    #
    #       {
    #         account_id: "AccountId", # required
    #         budget_name: "BudgetName", # required
    #         notification: { # required
    #           notification_type: "ACTUAL", # required, accepts ACTUAL, FORECASTED
    #           comparison_operator: "GREATER_THAN", # required, accepts GREATER_THAN, LESS_THAN, EQUAL_TO
    #           threshold: 1.0, # required
    #           threshold_type: "PERCENTAGE", # accepts PERCENTAGE, ABSOLUTE_VALUE
    #           notification_state: "OK", # accepts OK, ALARM
    #         },
    #         old_subscriber: { # required
    #           subscription_type: "SNS", # required, accepts SNS, EMAIL
    #           address: "SubscriberAddress", # required
    #         },
    #         new_subscriber: { # required
    #           subscription_type: "SNS", # required, accepts SNS, EMAIL
    #           address: "SubscriberAddress", # required
    #         },
    #       }
    #
    # @!attribute [rw] account_id
    #   The `accountId` that is associated with the budget whose subscriber
    #   you want to update.
    #   @return [String]
    #
    # @!attribute [rw] budget_name
    #   The name of the budget whose subscriber you want to update.
    #   @return [String]
    #
    # @!attribute [rw] notification
    #   The notification whose subscriber you want to update.
    #   @return [Types::Notification]
    #
    # @!attribute [rw] old_subscriber
    #   The previous subscriber that is associated with a budget
    #   notification.
    #   @return [Types::Subscriber]
    #
    # @!attribute [rw] new_subscriber
    #   The updated subscriber that is associated with a budget
    #   notification.
    #   @return [Types::Subscriber]
    #
    class UpdateSubscriberRequest < Struct.new(
      :account_id,
      :budget_name,
      :notification,
      :old_subscriber,
      :new_subscriber)
      SENSITIVE = []
      include Aws::Structure
    end

    # Response of UpdateSubscriber
    #
    class UpdateSubscriberResponse < Aws::EmptyStructure; end

  end
end
